@@ -4,7 +4,7 @@ from urllib.parse import quote
 import click
 
 from commands import test_settings, test_results
-from neoload_cli_lib import running_tools, tools, rest_crud, user_data
+from neoload_cli_lib import running_tools, tools, rest_crud, user_data, hooks
 
 
 @click.command()
@@ -37,6 +37,8 @@ def cli(name_or_id, scenario, detached, name, description, as_code, web_vu, sap_
         naming_pattern = "#${runID}"
     naming_pattern = naming_pattern.replace('${runID}', str(test_settings_json['nextRunId']))
 
+    hooks.trig("test.start", test_settings_json)
+
     # Sorry for that, post data are in the query string :'( :'(
     post_result = rest_crud.post(
         test_settings.get_end_point(_id) + '/start?' + create_data(naming_pattern, description, as_code, web_vu, sap_vu, citrix_vu),
